#
# encoding: UTF-8
# api: st2
# type: class
# title: global config object
# description: reads ~/.config/streamtuner/*.json files
#
# In the main application or module files which need access
# to a global conf object, just import this module as follows:
#
#   from config import conf
#
# Here conf is already an instantiation of the underlying
# Config class.
#


import os
import sys
import pson as json


#-- create a single instance of config object
conf = object()



#-- global configuration data               ---------------------------------------------
class ConfigDict(dict):
# nah. deriving from dict doesn't really work.


        # start
        def __init__(self):

            # prepare
            self.defaults()
            self.xdg()
            
            # runtime
            dirs = ["/usr/share/streamtuner2", "/usr/local/share/streamtuner2", sys.path[0], "."]
            self.share = [d for d in dirs if os.path.exists(d)][0]
            
            # settings from last session
            last = self.load("settings")
            if (last):
                self.__dict__.update(last)
            # store defaults in file
            else:
                self.save("settings")
                self.firstrun = 1

        # some defaults
        def defaults(self):
            self.browser = "sensible-browser"
            self.play = {
               "audio/mp3": "audacious %m3u",	# %u for url to .pls, %g for downloaded .m3u
               "audio/ogg": "audacious %pls",
               "audio/aac": "amarok %m3u",
               "audio/x-pn-realaudio": "vlc %m3u",
               "audio/*": "rythmbox %m3u",
               "*/*": "vlc %pls",
            }
            self.record = {
               "*/*": "x-terminal-emulator -e streamripper %srv",
            }
            self.tmp = os.environ.get("TEMP", "/tmp")
            self.max_streams = "120"
            self.show_bookmarks = 1
            self.show_favicons = 1
            self.load_favicon = 1
            self.retain_deleted = 1
            self.auto_save_appstate = 1
        
            
        # http://standards.freedesktop.org/basedir-spec/basedir-spec-0.6.html
        def xdg(self):
            home = os.environ.get("HOME", self.tmp)
            config = os.environ.get("XDG_CONFIG_HOME", home+"/.config")
            
            # storage dir
            self.dir = config + "/" + "streamtuner2"
            
            # create if necessary
            if (not os.path.exists(self.dir)):
                os.makedirs(self.dir)
           

        # store some configuration list/dict into a file                
        def save(self, name="settings", data=None):
            name = name + ".json"
            if (data == None):
                data = self.__dict__
            # check for subdir
            if (name.find("/") > 0):
                subdir = name[0:name.find("/")]
                subdir = self.dir + "/" + subdir
                if (not os.path.exists(subdir)):
                    os.mkdir(subdir)
            # write                        
            file = self.dir + "/" + name
            #json = cPickle
            json.dump(open(file, "w"), data)
            pass


        # retrieve data from config file            
        def load(self, name):
            name = name + ".json"
            file = self.dir + "/" + name
            if (os.path.exists(file)):
                #json = cPickle
                try:
                  return json.load(open(file, "r"))
                except (Exception), e:
                  print "PSON parsing error", e
                  return None
            pass
            



   
#-- actually fill global conf instance
conf = ConfigDict()


